@@ -1,7 +1,8 @@
 from petsc4py import PETSc
+import os
 import unittest
-import gc, weakref
-import warnings
+import gc
+import weakref
 
 # --------------------------------------------------------------------
 
@@ -11,8 +12,10 @@ import warnings
 
 # --------------------------------------------------------------------
 
-class BaseTestGC(object):
+PYSABI = os.path.basename(PETSc.__file__).split(".")[1] == "abi3"
 
+
+class BaseTestGC:
     def setUp(self):
         self.obj = self.CLASS().create(comm=PETSc.COMM_SELF)
 
@@ -21,12 +24,20 @@ class BaseTestGC(object):
         self.assertTrue(wref() is self.obj)
         self.obj = None
         gc.collect()
-        self.assertTrue(wref() is None)
+        if PYSABI:
+            # garbage collection is not supported
+            # the weak reference is still alive
+            self.assertTrue(wref() is not None)
+            self.assertEqual(wref().getRefCount(), 1)
+            wref().destroy()
+        else:
+            # the weak reference is gone
+            self.assertTrue(wref() is None)
+        del wref
         PETSc.garbage_cleanup()
 
     def make_weakref(self):
-        wref = weakref.ref(self.obj)
-        return wref
+        return weakref.ref(self.obj)
 
     def testCycleInSelf(self):
         self.obj.setAttr('myself', self.obj)
@@ -35,7 +46,9 @@ class BaseTestGC(object):
         self.obj.setAttr('mymeth', self.obj.view)
 
     def testCycleInInstance(self):
-        class A: pass
+        class A:
+            pass
+
         a = A()
         a.obj = self.obj
         self.obj.setAttr('myinst', a)
@@ -45,50 +58,67 @@ class BaseTestGC(object):
         self.testCycleInMethod()
         self.testCycleInInstance()
 
+
 # --------------------------------------------------------------------
 
+
 class TestGCVec(BaseTestGC, unittest.TestCase):
     CLASS = PETSc.Vec
 
+
 class TestGCVecSubType(TestGCVec):
     CLASS = type('_Vec', (PETSc.Vec,), {})
 
+
 class TestGCMat(BaseTestGC, unittest.TestCase):
     CLASS = PETSc.Mat
 
+
 class TestGCMatSubType(TestGCMat):
     CLASS = type('_Mat', (PETSc.Mat,), {})
 
+
 class TestGCPC(BaseTestGC, unittest.TestCase):
     CLASS = PETSc.PC
 
+
 class TestGCPCSubType(TestGCPC):
     CLASS = type('_PC', (PETSc.PC,), {})
 
+
 class TestGCKSP(BaseTestGC, unittest.TestCase):
     CLASS = PETSc.KSP
 
+
 class TestGCKSPSubType(TestGCKSP):
     CLASS = type('_KSP', (PETSc.KSP,), {})
 
+
 class TestGCSNES(BaseTestGC, unittest.TestCase):
     CLASS = PETSc.SNES
+
     def testCycleInAppCtx(self):
         self.obj.setAppCtx(self.obj)
 
+
 class TestGCSNESSubType(TestGCSNES):
     CLASS = type('_SNES', (PETSc.SNES,), {})
 
+
 class TestGCTS(BaseTestGC, unittest.TestCase):
     CLASS = PETSc.TS
+
     def testCycleInAppCtx(self):
         self.obj.setAppCtx(self.obj)
 
+
 class TestGCTSSubType(TestGCTS):
     CLASS = type('_TS', (PETSc.TS,), {})
+
     def testCycleInAppCtx(self):
         self.obj.setAppCtx(self.obj)
 
+
 # --------------------------------------------------------------------
 
 if __name__ == '__main__':
