@@ -3,29 +3,48 @@
 from petsc4py import PETSc
 import unittest
 from sys import getrefcount
-import numpy
+import numpy as np
 
 # --------------------------------------------------------------------
 
+
 class Function:
     def __call__(self, snes, x, f):
-        f[0] = (x[0]*x[0] + x[0]*x[1] - 3.0).item()
-        f[1] = (x[0]*x[1] + x[1]*x[1] - 6.0).item()
+        f[0] = (x[0] * x[0] + x[0] * x[1] - 3.0).item()
+        f[1] = (x[0] * x[1] + x[1] * x[1] - 6.0).item()
         f.assemble()
 
+
 class Jacobian:
     def __call__(self, snes, x, J, P):
-        P[0,0] = (2.0*x[0] + x[1]).item()
-        P[0,1] = (x[0]).item()
-        P[1,0] = (x[1]).item()
-        P[1,1] = (x[0] + 2.0*x[1]).item()
+        P[0, 0] = (2.0 * x[0] + x[1]).item()
+        P[0, 1] = (x[0]).item()
+        P[1, 0] = (x[1]).item()
+        P[1, 1] = (x[0] + 2.0 * x[1]).item()
         P.assemble()
-        if J != P: J.assemble()
+        if J != P:
+            J.assemble()
+
+
+class FunctionAL:
+    def __call__(self, snes, x, f):
+        load = snes.getNewtonALLoadParameter()
+        f[0] = (x[0] * x[0] + x[0] * x[1] - 3.0 * load).item()
+        f[1] = (x[0] * x[1] + x[1] * x[1] - 6.0 * load).item()
+        f.assemble()
+
+
+class FunctionALLoad:
+    def __call__(self, snes, x, f):
+        f[0] = 3.0
+        f[1] = 6.0
+        f.assemble()
+
 
 # --------------------------------------------------------------------
 
-class BaseTestSNES(object):
 
+class BaseTestSNES:
     SNES_TYPE = None
 
     def setUp(self):
@@ -47,15 +66,22 @@ class BaseTestSNES(object):
     def testTols(self):
         tols = self.snes.getTolerances()
         self.snes.setTolerances(*tols)
-        tnames = ('rtol', 'atol','stol', 'max_it')
-        tolvals = [getattr(self.snes, t) for t in  tnames]
+        tnames = ('rtol', 'atol', 'stol', 'max_it')
+        tolvals = [getattr(self.snes, t) for t in tnames]
         self.assertEqual(tuple(tols), tuple(tolvals))
+        dtol = self.snes.getDivergenceTolerance()
+        self.assertTrue(dtol > 0)
+        self.snes.setDivergenceTolerance(PETSc.UNLIMITED)
+        dtol = self.snes.getDivergenceTolerance()
+        self.assertEqual(dtol, PETSc.UNLIMITED)
+        self.snes.setDivergenceTolerance(PETSc.CURRENT)
+        self.assertEqual(dtol, PETSc.UNLIMITED)
 
     def testProperties(self):
         snes = self.snes
         #
-        snes.appctx = (1,2,3)
-        self.assertEqual(snes.appctx, (1,2,3))
+        snes.appctx = (1, 2, 3)
+        self.assertEqual(snes.appctx, (1, 2, 3))
         snes.appctx = None
         self.assertEqual(snes.appctx, None)
         #
@@ -70,31 +96,37 @@ class BaseTestSNES(object):
         self.assertEqual(snes.norm, 0)
         #
         rh, ih = snes.history
-        self.assertTrue(len(rh)==0)
-        self.assertTrue(len(ih)==0)
+        self.assertTrue(len(rh) == 0)
+        self.assertTrue(len(ih) == 0)
         #
         reason = PETSc.SNES.ConvergedReason.CONVERGED_ITS
         snes.reason = reason
         self.assertEqual(snes.reason, reason)
-        self.assertTrue(snes.converged)
-        self.assertFalse(snes.diverged)
-        self.assertFalse(snes.iterating)
+        self.assertTrue(snes.is_converged)
+        self.assertFalse(snes.is_diverged)
+        self.assertFalse(snes.is_iterating)
         reason = PETSc.SNES.ConvergedReason.DIVERGED_MAX_IT
         snes.reason = reason
         self.assertEqual(snes.reason, reason)
-        self.assertFalse(snes.converged)
-        self.assertTrue(snes.diverged)
-        self.assertFalse(snes.iterating)
+        self.assertFalse(snes.is_converged)
+        self.assertTrue(snes.is_diverged)
+        self.assertFalse(snes.is_iterating)
         reason = PETSc.SNES.ConvergedReason.CONVERGED_ITERATING
         snes.reason = reason
         self.assertEqual(snes.reason, reason)
-        self.assertFalse(snes.converged)
-        self.assertFalse(snes.diverged)
-        self.assertTrue(snes.iterating)
+        self.assertFalse(snes.is_converged)
+        self.assertFalse(snes.is_diverged)
+        self.assertTrue(snes.is_iterating)
         #
         self.assertFalse(snes.use_ew)
         self.assertFalse(snes.use_mf)
         self.assertFalse(snes.use_fd)
+        ouse = snes.use_ksp
+        self.assertEqual(ouse, snes.getUseKSP())
+        snes.use_ksp = not ouse
+        self.assertEqual(not ouse, snes.getUseKSP())
+        snes.setUseKSP(ouse)
+        self.assertEqual(ouse, snes.use_ksp)
 
     def testGetSetFunc(self):
         r, func = self.snes.getFunction()
@@ -131,7 +163,7 @@ class BaseTestSNES(object):
         self.assertFalse(P)
         self.assertTrue(jac is None)
         J = PETSc.Mat().create(PETSc.COMM_SELF)
-        J.setSizes([2,2])
+        J.setSizes([2, 2])
         J.setType(PETSc.Mat.Type.SEQAIJ)
         J.setUp()
         jac = Jacobian()
@@ -152,7 +184,7 @@ class BaseTestSNES(object):
 
     def testCompJac(self):
         J = PETSc.Mat().create(PETSc.COMM_SELF)
-        J.setSizes([2,2])
+        J.setSizes([2, 2])
         J.setType(PETSc.Mat.Type.SEQAIJ)
         J.setUp()
         jac = Jacobian()
@@ -178,7 +210,7 @@ class BaseTestSNES(object):
         upd2 = lambda snes, it: None
         refcnt2 = getrefcount(upd2)
         self.snes.setUpdate(upd2)
-        self.assertEqual(getrefcount(upd),  refcnt)
+        self.assertEqual(getrefcount(upd), refcnt)
         self.assertEqual(getrefcount(upd2), refcnt2 + 1)
         tmp = self.snes.getUpdate()[0]
         self.assertTrue(tmp is upd2)
@@ -194,36 +226,51 @@ class BaseTestSNES(object):
 
     def testSolve(self):
         J = PETSc.Mat().create(PETSc.COMM_SELF)
-        J.setSizes([2,2])
+        J.setSizes([2, 2])
         J.setType(PETSc.Mat.Type.SEQAIJ)
         J.setUp()
         r = PETSc.Vec().createSeq(2)
         x = PETSc.Vec().createSeq(2)
         b = PETSc.Vec().createSeq(2)
-        self.snes.setFunction(Function(), r)
+        if self.snes.getType() == PETSc.SNES.Type.NEWTONAL:
+            self.snes.setFunction(FunctionAL(), r)
+            self.snes.setNewtonALCorrectionType(PETSc.SNES.NewtonALCorrectionType.EXACT)
+            self.snes.setNewtonALFunction(FunctionALLoad())
+        else:
+            self.snes.setFunction(Function(), r)
         self.snes.setJacobian(Jacobian(), J)
-        x.setArray([2,3])
+
+        def _update(snes, it, cnt):
+             cnt += 1
+        cnt_up = np.array(0)
+        self.snes.setUpdate(_update, (cnt_up,) )
+
+        x.setArray([2, 3])
         b.set(0)
         self.snes.setConvergenceHistory()
         self.snes.setFromOptions()
         self.snes.solve(b, x)
+        self.snes.setUpdate(None)
         rh, ih = self.snes.getConvergenceHistory()
         self.snes.setConvergenceHistory(0, reset=True)
         rh, ih = self.snes.getConvergenceHistory()
         self.assertEqual(len(rh), 0)
         self.assertEqual(len(ih), 0)
-        self.assertAlmostEqual(abs(x[0]), 1.0, places=5)
-        self.assertAlmostEqual(abs(x[1]), 2.0, places=5)
+        if self.snes.getType() != PETSc.SNES.Type.NEWTONAL:
+            self.assertAlmostEqual(abs(x[0]), 1.0, places=5)
+            self.assertAlmostEqual(abs(x[1]), 2.0, places=5)
+        self.assertEqual(self.snes.getIterationNumber(), cnt_up)
         # XXX this test should not be here !
         reason = self.snes.callConvergenceTest(1, 0, 0, 0)
         self.assertTrue(reason > 0)
 
         # test interface
         x = self.snes.getSolution()
-        x.setArray([2,3])
+        x.setArray([2, 3])
         self.snes.solve()
-        self.assertAlmostEqual(abs(x[0]), 1.0, places=5)
-        self.assertAlmostEqual(abs(x[1]), 2.0, places=5)
+        if self.snes.getType() != PETSc.SNES.Type.NEWTONAL:
+            self.assertAlmostEqual(abs(x[0]), 1.0, places=5)
+            self.assertAlmostEqual(abs(x[1]), 2.0, places=5)
 
     def testResetAndSolve(self):
         self.snes.reset()
@@ -234,8 +281,10 @@ class BaseTestSNES(object):
 
     def testSetMonitor(self):
         reshist = {}
+
         def monitor(snes, its, fgnorm):
             reshist[its] = fgnorm
+
         refcnt = getrefcount(monitor)
         self.snes.setMonitor(monitor)
         self.assertEqual(getrefcount(monitor), refcnt + 1)
@@ -294,20 +343,20 @@ class BaseTestSNES(object):
         self.snes.setParamsEW(**params)
         params = self.snes.getParamsEW()
         self.assertEqual(params['version'], 1)
-        params['version'] = PETSc.DEFAULT
+        params['version'] = PETSc.CURRENT
         self.snes.setParamsEW(**params)
         params = self.snes.getParamsEW()
         self.assertEqual(params['version'], 1)
 
     def testMF(self):
-        #self.snes.setOptionsPrefix('MF-')
-        #opts = PETSc.Options(self.snes)
-        #opts['mat_mffd_type'] = 'ds'
-        #opts['snes_monitor']  = 'stdout'
-        #opts['ksp_monitor']   = 'stdout'
-        #opts['snes_view']     = 'stdout'
+        # self.snes.setOptionsPrefix('MF-')
+        # opts = PETSc.Options(self.snes)
+        # opts['mat_mffd_type'] = 'ds'
+        # opts['snes_monitor']  = 'stdout'
+        # opts['ksp_monitor']   = 'stdout'
+        # opts['snes_view']     = 'stdout'
         J = PETSc.Mat().create(PETSc.COMM_SELF)
-        J.setSizes([2,2])
+        J.setSizes([2, 2])
         J.setType(PETSc.Mat.Type.SEQAIJ)
         J.setUp()
         r = PETSc.Vec().createSeq(2)
@@ -323,8 +372,8 @@ class BaseTestSNES(object):
         self.snes.setUseMF(True)
         self.assertTrue(self.snes.getUseMF())
         self.snes.setFromOptions()
-        if self.snes.getType() != PETSc.SNES.Type.NEWTONTR:
-            x.setArray([2,3])
+        if self.snes.getType() == PETSc.SNES.Type.NEWTONLS:
+            x.setArray([2, 3])
             b.set(0)
             self.snes.solve(b, x)
             self.assertAlmostEqual(abs(x[0]), 1.0, places=5)
@@ -332,7 +381,7 @@ class BaseTestSNES(object):
 
     def testFDColor(self):
         J = PETSc.Mat().create(PETSc.COMM_SELF)
-        J.setSizes([2,2])
+        J.setSizes([2, 2])
         J.setType(PETSc.Mat.Type.SEQAIJ)
         J.setUp()
         r = PETSc.Vec().createSeq(2)
@@ -349,25 +398,107 @@ class BaseTestSNES(object):
         self.snes.setUseFD(True)
         self.assertTrue(self.snes.getUseFD())
         self.snes.setFromOptions()
-        x.setArray([2,3])
+        x.setArray([2, 3])
         b.set(0)
         self.snes.solve(b, x)
-        self.assertAlmostEqual(abs(x[0]), 1.0, places=4)
-        self.assertAlmostEqual(abs(x[1]), 2.0, places=4)
+        if self.snes.getType() != PETSc.SNES.Type.NEWTONAL:
+            self.assertAlmostEqual(abs(x[0]), 1.0, places=4)
+            self.assertAlmostEqual(abs(x[1]), 2.0, places=4)
 
     def testNPC(self):
-        self.snes.appctx = (1,2,3)
+        self.snes.appctx = (1, 2, 3)
         npc = self.snes.getNPC()
-        self.assertEqual(npc.appctx, (1,2,3))
+        self.assertEqual(npc.appctx, (1, 2, 3))
+
+    def testTRAPI(self):
+        newreg = (1,2,3)
+        newup = (1,2,3,4,5)
+        if self.snes.getType() == PETSc.SNES.Type.NEWTONTR:
+            defreg = self.snes.getTRTolerances()
+            defup = self.snes.getTRUpdateParameters()
+        self.snes.setTRTolerances(*newreg)
+        self.snes.setTRUpdateParameters(*newup)
+        if self.snes.getType() == PETSc.SNES.Type.NEWTONTR:
+            self.assertEqual(newreg, self.snes.getTRTolerances())
+            self.assertEqual(newup, self.snes.getTRUpdateParameters())
+        self.snes.setTRTolerances()
+        self.snes.setTRUpdateParameters()
+        if self.snes.getType() == PETSc.SNES.Type.NEWTONTR:
+            self.assertEqual(newreg, self.snes.getTRTolerances())
+            self.assertEqual(newup, self.snes.getTRUpdateParameters())
+        self.snes.setTRTolerances(*(PETSc.DETERMINE,)*3)
+        self.snes.setTRUpdateParameters(*(PETSc.DETERMINE,)*5)
+        if self.snes.getType() == PETSc.SNES.Type.NEWTONTR:
+            self.assertEqual(defreg, self.snes.getTRTolerances())
+            self.assertEqual(defup, self.snes.getTRUpdateParameters())
 
 # --------------------------------------------------------------------
 
+
 class TestSNESLS(BaseTestSNES, unittest.TestCase):
     SNES_TYPE = PETSc.SNES.Type.NEWTONLS
 
+
 class TestSNESTR(BaseTestSNES, unittest.TestCase):
     SNES_TYPE = PETSc.SNES.Type.NEWTONTR
 
+
+class TestSNESAL(BaseTestSNES, unittest.TestCase):
+    SNES_TYPE = PETSc.SNES.Type.NEWTONAL
+
+
+# --------------------------------------------------------------------
+
+
+class TestSNESLineSearchAPI(unittest.TestCase):
+    def test_create_destroy(self):
+        ls = PETSc.SNESLineSearch()
+        ls.create()
+        ls.destroy()
+
+    def test_type_set_get(self):
+        ls = PETSc.SNESLineSearch().create()
+        ls.setType(PETSc.SNESLineSearch.Type.BASIC)
+        typ = ls.getType()
+        self.assertEqual(typ, 'basic')
+        ls.destroy()
+
+    def test_tolerances_set_get(self):
+        ls = PETSc.SNESLineSearch().create()
+        ls.setTolerances(rtol=0.125, atol=3, minstep=4, ltol=5, maxstep=6, max_its=7)
+        minstep, maxstep, rtol, atol, ltol, max_its = ls.getTolerances()
+        self.assertEqual(rtol, 0.125)
+        self.assertEqual(atol, 3)
+        self.assertEqual(minstep, 4)
+        self.assertEqual(ltol, 5)
+        self.assertEqual(maxstep, 6)
+        self.assertEqual(max_its, 7)
+        ls.destroy()
+
+    def test_order_set_get(self):
+        ls = PETSc.SNESLineSearch().create()
+        ls.setOrder(2)
+        order = ls.getOrder()
+        self.assertEqual(order, 2)
+        ls.destroy()
+
+    def test_set_from_options(self):
+        ls = PETSc.SNESLineSearch().create()
+        ls.setFromOptions()
+        # ls.view()
+        ls.destroy()
+
+    def test_snes_linesearch_property(self):
+        snes = PETSc.SNES().create()
+        ls = snes.getLineSearch()
+        self.assertTrue(isinstance(ls, PETSc.SNESLineSearch))
+        # Set/get via property
+        self.assertEqual(snes.linesearch, ls)
+        snes.linesearch = ls
+        self.assertEqual(snes.linesearch, ls)
+        snes.destroy()
+
+
 # --------------------------------------------------------------------
 
 if __name__ == '__main__':
